pub enum Visibility {
Public,
Protected,
Private(String),
}Expand description
The visibility of a property of an object.
PHP writes the names of protected and private properties with a prefix
(\0*\0name and \0Class\0name). The deserializer passes on the bare
name and the visibility as event data of the key (see
take_visibility), the serializer adds the prefix again if a key has
a visibility (see set_visibility).
Variants
Public
A public property (no prefix).
Protected
A protected property (\0*\0name).
Private(String)
A private property of the given class (\0Class\0name).