set_visibility

Function set_visibility 

pub fn set_visibility(state: &mut State, visibility: Visibility)
Sets the visibility of the key that is serialized.

It must be called from Serialize::serialize of the key. The key is written with the prefix of the visibility.