Object

Struct Object 

pub struct Object<T> {
    pub class: Option<String>,
    pub value: T,
}
A value with the class of a PHP object.

When deserialized the class of the value (if there is one) is captured, when serialized the value is written as an object of the class:

use std::collections::BTreeMap;
use deser_php::Object;

let input = br#"O:4:"User":1:{s:4:"name";s:4:"Jane";}"#;
let user: Object<BTreeMap<String, String>> = deser_php::from_slice(input).unwrap();
assert_eq!(user.class.as_deref(), Some("User"));
assert_eq!(user.value["name"], "Jane");
assert_eq!(deser_php::to_vec(&user).unwrap(), input);

Maps are written as objects, strings as enum cases (E:) and bytes as custom serialized objects (C:). Other formats do not have classes. When deserializing from such formats, the class is None, when serializing it’s ignored.

Fields

class: Option<String>

The class of the value.

value: T

The value.

Implementations

Source

impl<T> Object<T>

pub fn new<S: Into<String>>(class: S, value: T) -> Object<T>

Creates a value with a class.

pub fn into_inner(self) -> T

Returns the inner value.