pub struct Serializer { /* private fields */ }Expand description
Serializes values into PHP’s serialization format.
The values are appended to the output one after another (they can be
read back with Deserializer::iter).
use deser_php::Serializer;
let mut serializer = Serializer::new();
serializer.serialize(&true).unwrap();
serializer.serialize(&"hi").unwrap();
assert_eq!(serializer.output(), b"b:1;s:2:\"hi\";");The serializer is also the stream serializer of the format (see
StreamSerializer). Values are written once
they are complete as the lengths of arrays are written in front of
them. To write to a Write use
SerializerConfig::writer.
Implementations
Sourceimpl Serializer
impl Serializer
Sourcepub fn new() -> Serializer
pub fn new() -> Serializer
Creates a serializer.
Sourcepub fn with_config(config: SerializerConfig) -> Serializer
pub fn with_config(config: SerializerConfig) -> Serializer
Creates a serializer with the given configuration.
Sourcepub fn config(&self) -> &SerializerConfig
pub fn config(&self) -> &SerializerConfig
Returns the configuration.
Sourcepub fn serialize<T: Serialize + ?Sized>(
&mut self,
value: &T,
) -> Result<(), Error>
pub fn serialize<T: Serialize + ?Sized>( &mut self, value: &T, ) -> Result<(), Error>
Serializes a value and appends it to the output.