StreamDeserializer

Struct StreamDeserializer 

pub struct StreamDeserializer { /* private fields */ }
Reads values of PHP’s serialization format from a stream (see deser::stream).

Values are validated before they are emitted, which needs the whole value: the stream is read to the end and then its values (which can be concatenated) are deserialized one after another.

use deser_php::DeserializerConfig;

let mut reader = DeserializerConfig::new().reader(&b"i:1;s:3:\"two\";"[..]);
assert_eq!(reader.read::<u32>().unwrap(), Some(1));
assert_eq!(reader.read::<String>().unwrap().as_deref(), Some("two"));
assert_eq!(reader.read::<String>().unwrap(), None);

Implementations

Source

impl StreamDeserializer

pub fn new() -> StreamDeserializer

Creates a stream deserializer.

pub fn with_config(config: DeserializerConfig) -> StreamDeserializer

Creates a stream deserializer with the given configuration.

pub fn config(&self) -> &DeserializerConfig

Returns the configuration.