pub fn set_visibility(state: &mut State, visibility: Visibility)Expand description
Sets the visibility of the key that is serialized.
It must be called from Serialize::serialize of the key. The key is
written with the prefix of the visibility.
pub fn set_visibility(state: &mut State, visibility: Visibility)Sets the visibility of the key that is serialized.
It must be called from Serialize::serialize of the key. The key is
written with the prefix of the visibility.