pub fn take_visibility(state: &mut State) -> Option<Visibility>Expand description
Takes the visibility of the current key from the state.
Returns None for keys that are not names of protected or private
properties.
pub fn take_visibility(state: &mut State) -> Option<Visibility>Takes the visibility of the current key from the state.
Returns None for keys that are not names of protected or private
properties.